Index: applications/editors/josm/plugins/pt_assistant/src/org/openstreetmap/josm/plugins/pt_assistant/data/PTStop.java
===================================================================
--- applications/editors/josm/plugins/pt_assistant/src/org/openstreetmap/josm/plugins/pt_assistant/data/PTStop.java	(revision 33467)
+++ applications/editors/josm/plugins/pt_assistant/src/org/openstreetmap/josm/plugins/pt_assistant/data/PTStop.java	(revision 33468)
@@ -139,12 +139,12 @@
         }
 
         // Look for a stop position within 0.002 degrees (around 100 m) of this
         // platform:
 
         LatLon platformCenter = platform.getBBox().getCenter();
-        Double ax = platformCenter.getX() - 0.002;
-        Double bx = platformCenter.getX() + 0.002;
-        Double ay = platformCenter.getY() - 0.002;
-        Double by = platformCenter.getY() + 0.002;
+        Double ax = platformCenter.getX() - 0.001;
+        Double bx = platformCenter.getX() + 0.001;
+        Double ay = platformCenter.getY() - 0.001;
+        Double by = platformCenter.getY() + 0.001;
         BBox platformBBox = new BBox(ax, ay, bx, by);
 
@@ -155,6 +155,7 @@
             if (platformBBox.bounds(currentNode.getBBox())
                     && currentNode.hasTag("public_transport", "stop_position")
-                    && (platName != null && nodeName != null)
-                    && platName.equals(nodeName)) {
+                    && (platName == null
+                        || nodeName == null
+                        || platName.equals(nodeName))) {
                 potentialStopPositions.add(currentNode);
             }
@@ -139,12 +139,12 @@
         }
 
-        // Look for a stop position within 0.002 degrees (around 100 m) of this
+        // Look for a stop position within 0.001 degrees (around 50 m) of this
         // platform:
 
